St8Animation class

Constructors

St8Animation()

Properties

animations List<St8AnimationState>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isLoop bool
getter/setter pair
isReverse bool
getter/setter pair
repeatCount int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

moveTo(double x, double y, {Duration? duration, Curve? curve}) St8Animation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
opacityTo(double opacity, {Duration? duration, Curve? curve}) St8Animation
rotateTo(double turns, {Duration? duration, Curve? curve, Alignment? alignment}) St8Animation
scaleTo(double scale, {Duration? duration, Curve? curve, Alignment? alignment}) St8Animation
stateTo(St8AnimationState animation) St8Animation
toString() String
A string representation of this object.
inherited
wait(Duration duration) St8Animation

Operators

operator ==(Object other) bool
The equality operator.
inherited