St8Reference class

Constructors

St8Reference(String _key, Type type)

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
final
value ↔ dynamic
getter/setter pair

Methods

lock() St8Reference
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh() St8Reference
store() St8Reference
to(dynamic newValue) St8Reference
toString() String
A string representation of this object.
inherited
unlock() St8Reference

Operators

operator ==(Object other) bool
The equality operator.
inherited